.. currentmodule:: sardana.pool.poolcountertimer

:mod:`~sardana.pool.poolcountertimer`
==========================================

.. automodule:: sardana.pool.poolcountertimer

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolCounterTimer`

PoolCounterTimer
-------------------

.. inheritance-diagram:: PoolCounterTimer
    :parts: 1
    
.. autoclass:: PoolCounterTimer
    :show-inheritance:
    :members:
    :undoc-members:
